@@ -8,12 +8,18 @@
 #'
 #' @return A data frame with two columns: Parameter name and effective sample size (ESS).
 #'
-#' @details **Effective Sample (ESS)** should be as large as possible, altough for most applications, an effective sample size greater than 1,000 is sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the number of independent samples with the same estimation power as the N autocorrelated samples. It is is a measure of \dQuote{how much independent information there is in autocorrelated chains} (*Kruschke 2015, p182-3*).
+#' @details **Effective Sample (ESS)** should be as large as possible, altough
+#'   for most applications, an effective sample size greater than 1,000 is
+#'   sufficient for stable estimates (Bürkner, 2017). The ESS corresponds to the
+#'   number of independent samples with the same estimation power as the N
+#'   autocorrelated samples. It is is a measure of \dQuote{how much independent
+#'   information there is in autocorrelated chains} (*Kruschke 2015, p182-3*).
 #'
-#' @references \itemize{
-#'   \item Kruschke, J. (2014). Doing Bayesian data analysis: A tutorial with R, JAGS, and Stan. Academic Press.
-#'   \item Bürkner, P. C. (2017). brms: An R package for Bayesian multilevel models using Stan. Journal of Statistical Software, 80(1), 1-28
-#' }
+#' @references
+#' - Kruschke, J. (2014). Doing Bayesian data analysis: A tutorial with R, JAGS,
+#'   and Stan. Academic Press.
+#' - Bürkner, P. C. (2017). brms: An R package for Bayesian multilevel models
+#'   using Stan. Journal of Statistical Software, 80(1), 1-28
 #'
 #' @examplesIf require("rstanarm")
 #' \donttest{
@@ -78,7 +84,7 @@ effective_sample.brmsfit <- function(model,
 #' @export
 effective_sample.stanreg <- function(model,
                                      effects = c("fixed", "random", "all"),
-                                     component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                                     component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), # nolint
                                      parameters = NULL,
                                      ...) {
   # check arguments
@@ -108,7 +114,7 @@ effective_sample.stanreg <- function(model,
 #' @export
 effective_sample.stanmvreg <- function(model,
                                        effects = c("fixed", "random", "all"),
-                                       component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                                       component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), # nolint
                                        parameters = NULL,
                                        ...) {
   # check arguments
