@@ -1,22 +1,34 @@
 #' Density Estimation
 #'
-#' This function is a wrapper over different methods of density estimation. By default, it uses the base R `density` with by default uses a different smoothing bandwidth (`"SJ"`) from the legacy default implemented the base R `density` function (`"nrd0"`). However, Deng and Wickham suggest that `method = "KernSmooth"` is the fastest and the most accurate.
+#' This function is a wrapper over different methods of density estimation. By
+#' default, it uses the base R `density` with by default uses a different smoothing
+#' bandwidth (`"SJ"`) from the legacy default implemented the base R `density`
+#' function (`"nrd0"`). However, Deng and Wickham suggest that `method = "KernSmooth"`
+#' is the fastest and the most accurate.
 #'
 #' @inheritParams hdi
 #' @inheritParams stats::density
-#' @param bw See the eponymous argument in `density`. Here, the default has been changed for `"SJ"`, which is recommended.
-#' @param ci The confidence interval threshold. Only used when `method = "kernel"`. This feature is experimental, use with caution.
-#' @param method Density estimation method. Can be `"kernel"` (default), `"logspline"` or `"KernSmooth"`.
+#' @param bw See the eponymous argument in `density`. Here, the default has been
+#' changed for `"SJ"`, which is recommended.
+#' @param ci The confidence interval threshold. Only used when `method = "kernel"`.
+#' This feature is experimental, use with caution.
+#' @param method Density estimation method. Can be `"kernel"` (default), `"logspline"`
+#' or `"KernSmooth"`.
 #' @param precision Number of points of density data. See the `n` parameter in `density`.
 #' @param extend Extend the range of the x axis by a factor of `extend_scale`.
-#' @param extend_scale Ratio of range by which to extend the x axis. A value of `0.1` means that the x axis will be extended by `1/10` of the range of the data.
-#' @param select Character vector of column names. If NULL (the default), all numeric variables will be selected. Other arguments from [datawizard::find_columns()] (such as `exclude`) can also be used.
-#' @param at Optional character vector. If not `NULL` and input is a data frame, density estimation is performed for each group (subsets) indicated by `at`. See examples.
-#' @param group_by Deprecated in favour of `at`.
+#' @param extend_scale Ratio of range by which to extend the x axis. A value of `0.1`
+#' means that the x axis will be extended by `1/10` of the range of the data.
+#' @param select Character vector of column names. If `NULL` (the default), all
+#' numeric variables will be selected. Other arguments from
+#' `datawizard::extract_column_names()` (such as `exclude`) can also be used.
+#' @param by Optional character vector. If not `NULL` and input is a data frame,
+#' density estimation is performed for each group (subsets) indicated by `by`.
+#' See examples.
+#' @param at Deprecated in favour of `by`.
 #'
 #' @note There is also a [`plot()`-method](https://easystats.github.io/see/articles/bayestestR.html) implemented in the \href{https://easystats.github.io/see/}{\pkg{see}-package}.
 #'
-#' @examplesIf requireNamespace("logspline", quietly = TRUE) && requireNamespace("KernSmooth", quietly = TRUE) && requireNamespace("mclust", quietly = TRUE)
+#' @examplesIf require("logspline") && require("KernSmooth") && require("mclust") && require("emmeans") && require("rstanarm") && require("brms")
 #' library(bayestestR)
 #'
 #' set.seed(1)
@@ -58,17 +70,19 @@
 #' head(estimate_density(iris, select = "Sepal.Width"))
 #'
 #' # Grouped data
-#' head(estimate_density(iris, at = "Species"))
-#' head(estimate_density(iris$Petal.Width, at = iris$Species))
-#' \dontrun{
+#' head(estimate_density(iris, by = "Species"))
+#' head(estimate_density(iris$Petal.Width, by = iris$Species))
+#' \donttest{
 #' # rstanarm models
 #' # -----------------------------------------------
 #' library(rstanarm)
-#' model <- stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
+#' model <- suppressWarnings(
+#'   stan_glm(mpg ~ wt + gear, data = mtcars, chains = 2, iter = 200, refresh = 0)
+#' )
 #' head(estimate_density(model))
 #'
 #' library(emmeans)
-#' head(estimate_density(emtrends(model, ~1, "wt")))
+#' head(estimate_density(emtrends(model, ~1, "wt", data = mtcars)))
 #'
 #' # brms models
 #' # -----------------------------------------------
@@ -147,12 +161,8 @@ estimate_density.default <- function(x, ...) {
 }
 
 
-
 # Methods -----------------------------------------------------------------
 
-
-
-
 #' @export
 estimate_density.numeric <- function(x,
                                      method = "kernel",
@@ -161,33 +171,34 @@ estimate_density.numeric <- function(x,
                                      extend_scale = 0.1,
                                      bw = "SJ",
                                      ci = NULL,
+                                     by = NULL,
                                      at = NULL,
-                                     group_by = NULL,
                                      ...) {
   # TODO remove deprecation warning
   # Sanity
-  if (!is.null(group_by)) {
+  if (!is.null(at)) {
     insight::format_warning(
-      "The `group_by` argument is deprecated and might be removed in a future update. Please replace by `at`."
+      "The `at` argument is deprecated and might be removed in a future update. Please replace by `by`."
     )
-    at <- group_by
+    by <- at
   }
 
-  if (!is.null(at)) {
-    if (length(at) == 1) {
-      insight::format_error(
-        "`at` must be either the name of a group column if a data frame is entered as input, or in this case (where a single vector was passed) a vector of same length."
-      )
+  if (!is.null(by)) {
+    if (length(by) == 1) {
+      insight::format_error(paste0(
+        "`by` must be either the name of a group column if a data frame is entered as input,",
+        " or in this case (where a single vector was passed) a vector of same length."
+      ))
     }
     out <- estimate_density(
-      data.frame(V1 = x, Group = at, stringsAsFactors = FALSE),
+      data.frame(V1 = x, Group = by, stringsAsFactors = FALSE),
       method = method,
       precision = precision,
       extend = extend,
       extend_scale = extend_scale,
       bw = bw,
       ci = ci,
-      at = "Group",
+      by = "Group",
       ...
     )
     out$Parameter <- NULL
@@ -208,10 +219,8 @@ estimate_density.numeric <- function(x,
 }
 
 
-
-
-
 #' @rdname estimate_density
+#' @inheritParams p_direction
 #' @export
 estimate_density.data.frame <- function(x,
                                         method = "kernel",
@@ -221,16 +230,37 @@ estimate_density.data.frame <- function(x,
                                         bw = "SJ",
                                         ci = NULL,
                                         select = NULL,
+                                        by = NULL,
                                         at = NULL,
-                                        group_by = NULL,
+                                        rvar_col = NULL,
                                         ...) {
-  # Sanity
-  if (!is.null(group_by)) {
-    insight::format_warning("The 'group_by' argument is deprecated and might be removed in a future update. Please replace by 'at'.")
-    at <- group_by
+  x_rvar <- .possibly_extract_rvar_col(x, rvar_col)
+  if (length(x_rvar) > 0L) {
+    cl <- match.call()
+    cl[[1]] <- bayestestR::estimate_density
+    cl$x <- x_rvar
+    cl$rvar_col <- NULL
+    out <- eval.parent(cl)
+
+    obj_name <- insight::safe_deparse_symbol(substitute(x))
+    attr(out, "object_name") <- sprintf('%s[["%s"]]', obj_name, rvar_col)
+
+    out <- .append_datagrid(out, x, long = TRUE)
+    class(out) <- .set_density_class(out)
+    return(out)
   }
 
-  if (is.null(at)) {
+
+  # Sanity
+  if (!is.null(at)) {
+    insight::format_warning(paste0(
+      "The `at` argument is deprecated and might be removed in a future update.",
+      " Please replace by `by`."
+    ))
+    by <- at
+  }
+
+  if (is.null(by)) {
     # No grouping -------------------
     out <- .estimate_density_df(
       x = x,
@@ -244,9 +274,9 @@ estimate_density.data.frame <- function(x,
       ...
     )
   } else {
-    # Deal with at- grouping --------
+    # Deal with by- grouping --------
 
-    groups <- insight::get_datagrid(x[, at, drop = FALSE], at = at) # Get combinations
+    groups <- insight::get_datagrid(x[, by, drop = FALSE], by = by) # Get combinations
     out <- data.frame()
     for (row in seq_len(nrow(groups))) {
       subdata <- datawizard::data_match(x, groups[row, , drop = FALSE])
@@ -272,7 +302,25 @@ estimate_density.data.frame <- function(x,
 
 
 #' @export
-estimate_density.draws <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, select = NULL, at = NULL, group_by = NULL, ...) {
+estimate_density.draws <- function(x,
+                                   method = "kernel",
+                                   precision = 2^10,
+                                   extend = FALSE,
+                                   extend_scale = 0.1,
+                                   bw = "SJ",
+                                   ci = NULL,
+                                   select = NULL,
+                                   by = NULL,
+                                   at = NULL,
+                                   ...) {
+  if (!is.null(at)) {
+    insight::format_warning(paste0(
+      "The `at` argument is deprecated and might be removed in a future update.",
+      " Please replace by `by`."
+    ))
+    by <- at
+  }
+
   estimate_density(
     .posterior_draws_to_df(x),
     method = method,
@@ -281,8 +329,7 @@ estimate_density.draws <- function(x, method = "kernel", precision = 2^10, exten
     extend_scale = extend_scale,
     bw = bw,
     select = select,
-    at = at,
-    group_by = group_by
+    by = by
   )
 }
 
@@ -290,54 +337,63 @@ estimate_density.draws <- function(x, method = "kernel", precision = 2^10, exten
 estimate_density.rvar <- estimate_density.draws
 
 
-.estimate_density_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, select = NULL, ...) {
-  # TODO: replace by exposed select argument
-  if (is.null(select)) {
-    x <- .select_nums(x)
-  } else {
-    x <- datawizard::data_select(x, select, ...)
-  }
-
-  out <- sapply(x, estimate_density, method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, simplify = FALSE)
-  for (i in names(out)) {
-    if (nrow(out[[i]]) == 0) {
-      insight::format_warning(paste0("'", i, "', or one of its 'at' groups, is empty and has no density information."))
-    } else {
-      out[[i]]$Parameter <- i
-    }
-  }
-  out <- do.call(rbind, out)
-
-  row.names(out) <- NULL
-  out[, c("Parameter", "x", "y")]
-}
-
-
 #' @export
-estimate_density.grouped_df <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ci = NULL, select = NULL, ...) {
+estimate_density.grouped_df <- function(x,
+                                        method = "kernel",
+                                        precision = 2^10,
+                                        extend = FALSE,
+                                        extend_scale = 0.1,
+                                        bw = "SJ",
+                                        ci = NULL,
+                                        select = NULL,
+                                        ...) {
   groups <- .group_vars(x)
   ungrouped_x <- as.data.frame(x)
 
   xlist <- split(ungrouped_x, ungrouped_x[groups])
 
   out <- lapply(names(xlist), function(group) {
-    dens <- estimate_density(xlist[[group]], method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ci = ci, select = select, ...)
+    dens <- estimate_density(
+      xlist[[group]],
+      method = method,
+      precision = precision,
+      extend = extend,
+      extend_scale = extend_scale,
+      bw = bw,
+      ci = ci,
+      select = select,
+      ...
+    )
     dens$Group <- group
     dens
   })
   do.call(rbind, out)
 }
 
+# to avoid class conflicts - e.g., numeric variables imported with the
+# haven package are of class "haven_labelled" and "double", which causes
+# problems with the generic or numeric method.
 
 #' @export
-estimate_density.emmGrid <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", ...) {
-  x <- insight::get_parameters(x)
+estimate_density.double <- estimate_density.numeric
 
-  out <- estimate_density(x,
+#' @export
+estimate_density.emmGrid <- function(x,
+                                     method = "kernel",
+                                     precision = 2^10,
+                                     extend = FALSE,
+                                     extend_scale = 0.1,
+                                     bw = "SJ",
+                                     ...) {
+  xdf <- insight::get_parameters(x)
+
+  out <- estimate_density(xdf,
     method = method, precision = precision,
     extend = extend, extend_scale = extend_scale,
     bw = bw, ...
   )
+
+  out <- .append_datagrid(out, x, long = TRUE)
   class(out) <- .set_density_class(out)
   out
 }
@@ -345,16 +401,59 @@ estimate_density.emmGrid <- function(x, method = "kernel", precision = 2^10, ext
 #' @export
 estimate_density.emm_list <- estimate_density.emmGrid
 
+#' @export
+estimate_density.slopes <- function(x,
+                                    method = "kernel",
+                                    precision = 2^10,
+                                    extend = FALSE,
+                                    extend_scale = 0.1,
+                                    bw = "SJ",
+                                    ...) {
+  xdf <- .get_marginaleffects_draws(x)
+
+  out <- estimate_density(xdf,
+    method = method, precision = precision,
+    extend = extend, extend_scale = extend_scale,
+    bw = bw, ...
+  )
+
+  out <- .append_datagrid(out, x, long = TRUE)
+  class(out) <- .set_density_class(out)
+  out
+}
+
+#' @export
+estimate_density.predictions <- estimate_density.slopes
+
+#' @export
+estimate_density.comparisons <- estimate_density.slopes
 
 
 #' @export
-estimate_density.stanreg <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", effects = c("fixed", "random", "all"), component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"), parameters = NULL, ...) {
+estimate_density.stanreg <- function(x,
+                                     method = "kernel",
+                                     precision = 2^10,
+                                     extend = FALSE,
+                                     extend_scale = 0.1,
+                                     bw = "SJ",
+                                     effects = c("fixed", "random", "all"),
+                                     component = c("location", "all", "conditional", "smooth_terms", "sigma", "distributional", "auxiliary"),
+                                     parameters = NULL,
+                                     ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  out <- estimate_density(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
-  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  out <- estimate_density(
+    insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+    method = method,
+    precision = precision,
+    extend = extend,
+    extend_scale = extend_scale,
+    bw = bw,
+    ...
+  )
 
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- .set_density_class(out)
   out
 }
@@ -366,40 +465,82 @@ estimate_density.stanfit <- estimate_density.stanreg
 estimate_density.blavaan <- estimate_density.stanreg
 
 
-
 #' @export
-estimate_density.brmsfit <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", effects = c("fixed", "random", "all"), component = c("conditional", "zi", "zero_inflated", "all"), parameters = NULL, ...) {
+estimate_density.brmsfit <- function(x,
+                                     method = "kernel",
+                                     precision = 2^10,
+                                     extend = FALSE,
+                                     extend_scale = 0.1,
+                                     bw = "SJ",
+                                     effects = c("fixed", "random", "all"),
+                                     component = c("conditional", "zi", "zero_inflated", "all"),
+                                     parameters = NULL,
+                                     ...) {
   effects <- match.arg(effects)
   component <- match.arg(component)
 
-  out <- estimate_density(insight::get_parameters(x, effects = effects, component = component, parameters = parameters), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
-  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  out <- estimate_density(
+    insight::get_parameters(x, effects = effects, component = component, parameters = parameters),
+    method = method,
+    precision = precision,
+    extend = extend,
+    extend_scale = extend_scale,
+    bw = bw,
+    ...
+  )
 
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- .set_density_class(out)
   out
 }
 
 
-
-
 #' @export
-estimate_density.MCMCglmm <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", parameters = NULL, ...) {
+estimate_density.MCMCglmm <- function(x,
+                                      method = "kernel",
+                                      precision = 2^10,
+                                      extend = FALSE,
+                                      extend_scale = 0.1,
+                                      bw = "SJ",
+                                      parameters = NULL,
+                                      ...) {
   nF <- x$Fixed$nfl
-  out <- estimate_density(as.data.frame(x$Sol[, 1:nF, drop = FALSE]), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
-  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+  out <- estimate_density(
+    as.data.frame(x$Sol[, 1:nF, drop = FALSE]),
+    method = method,
+    precision = precision,
+    extend = extend,
+    extend_scale = extend_scale,
+    bw = bw,
+    ...
+  )
 
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- .set_density_class(out)
   out
 }
 
 
-
-
 #' @export
-estimate_density.mcmc <- function(x, method = "kernel", precision = 2^10, extend = FALSE, extend_scale = 0.1, bw = "SJ", parameters = NULL, ...) {
-  out <- estimate_density(insight::get_parameters(x, parameters = parameters), method = method, precision = precision, extend = extend, extend_scale = extend_scale, bw = bw, ...)
-  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
+estimate_density.mcmc <- function(x,
+                                  method = "kernel",
+                                  precision = 2^10,
+                                  extend = FALSE,
+                                  extend_scale = 0.1,
+                                  bw = "SJ",
+                                  parameters = NULL,
+                                  ...) {
+  out <- estimate_density(
+    insight::get_parameters(x, parameters = parameters),
+    method = method,
+    precision = precision,
+    extend = extend,
+    extend_scale = extend_scale,
+    bw = bw,
+    ...
+  )
 
+  attr(out, "object_name") <- insight::safe_deparse_symbol(substitute(x))
   class(out) <- .set_density_class(out)
   out
 }
@@ -447,7 +588,6 @@ estimate_density.bamlss <- function(x,
 }
 
 
-
 #' Coerce to a Data Frame
 #'
 #' @inheritParams base::as.data.frame
@@ -458,8 +598,48 @@ as.data.frame.density <- function(x, ...) {
 }
 
 
+# helper ------------------
 
+.estimate_density_df <- function(x,
+                                 method = "kernel",
+                                 precision = 2^10,
+                                 extend = FALSE,
+                                 extend_scale = 0.1,
+                                 bw = "SJ",
+                                 ci = NULL,
+                                 select = NULL,
+                                 ...) {
+  # TODO: replace by exposed select argument
+  if (is.null(select)) {
+    x <- .select_nums(x)
+  } else {
+    x <- datawizard::data_select(x, select, ...)
+  }
 
+  out <- sapply(
+    x,
+    estimate_density,
+    method = method,
+    precision = precision,
+    extend = extend,
+    extend_scale = extend_scale,
+    bw = bw,
+    ci = ci,
+    simplify = FALSE
+  )
+
+  for (i in names(out)) {
+    if (nrow(out[[i]]) == 0) {
+      insight::format_warning(paste0("`", i, "`, or one of its groups specified in `by`, is empty and has no density information."))
+    } else {
+      out[[i]]$Parameter <- i
+    }
+  }
+  out <- do.call(rbind, out)
+
+  row.names(out) <- NULL
+  out[, c("Parameter", "x", "y")]
+}
 
 
 #' Density Probability at a Given Value
@@ -478,15 +658,11 @@ as.data.frame.density <- function(x, ...) {
 #' density_at(posterior, c(0, 1))
 #' @export
 density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
-  density <- estimate_density(posterior, precision = precision, method = method, ...)
-  stats::approx(density$x, density$y, xout = x)$y
+  posterior_density <- estimate_density(posterior, precision = precision, method = method, ...)
+  stats::approx(posterior_density$x, posterior_density$y, xout = x)$y
 }
 
 
-
-
-
-
 # Different functions -----------------------------------------------------
 
 .estimate_density_kernel <- function(x, x_range, precision, bw, ci = 0.95, ...) {
@@ -495,7 +671,7 @@ density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
   dots[c("effects", "component", "parameters")] <- NULL
 
   # Get the kernel density estimation (KDE)
-  args <- c(dots, list(
+  my_args <- c(dots, list(
     x = x,
     n = precision,
     bw = bw,
@@ -503,8 +679,8 @@ density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
     to = x_range[2]
   ))
   fun <- get("density", asNamespace("stats"))
-  kde <- suppressWarnings(do.call("fun", args))
-  df <- as.data.frame(kde)
+  kde <- suppressWarnings(do.call("fun", my_args))
+  my_df <- as.data.frame(kde)
 
   # Get CI (https://bookdown.org/egarpor/NP-UC3M/app-kde-ci.html)
   if (!is.null(ci)) {
@@ -512,18 +688,16 @@ density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
     # R(K) for a normal
     Rk <- 1 / (2 * sqrt(pi))
     # Estimate the SD
-    sd_kde <- sqrt(df$y * Rk / (length(x) * h))
+    sd_kde <- sqrt(my_df$y * Rk / (length(x) * h))
     # CI with estimated variance
     z_alpha <- stats::qnorm(ci)
-    df$CI_low <- df$y - z_alpha * sd_kde
-    df$CI_high <- df$y + z_alpha * sd_kde
+    my_df$CI_low <- my_df$y - z_alpha * sd_kde
+    my_df$CI_high <- my_df$y + z_alpha * sd_kde
   }
-  df
+  my_df
 }
 
 
-
-
 .estimate_density_logspline <- function(x, x_range, precision, ...) {
   insight::check_if_installed("logspline")
   x_axis <- seq(x_range[1], x_range[2], length.out = precision)
@@ -546,8 +720,6 @@ density_at <- function(posterior, x, precision = 2^10, method = "kernel", ...) {
 }
 
 
-# helper ----------------------------------------------------------
-
 .set_density_df_class <- function(out) {
   setdiff(
     unique(c("estimate_density_df", "see_estimate_density_df", class(out))),
