@@ -1,10 +1,3 @@
-# Reexports models ------------------------
-
-#' @importFrom insight print_html
-#' @export
-insight::print_html
-
-
 #' @export
 print_html.describe_posterior <- function(x, digits = 2, caption = "Summary of Posterior Distribution", ...) {
   .print_html_default(x = x, digits = digits, caption = caption, ...)
@@ -35,25 +28,43 @@ print_html.p_map <- function(x, digits = 2, caption = "MAP-based p-value", ...)
 }
 
 
-
 #' @export
 print_html.p_rope <- function(x, digits = 2, ...) {
-  caption <- sprintf(
-    "Proportion of samples inside the ROPE [%.*f, %.*f]",
-    digits, x$ROPE_low[1], digits, x$ROPE_high[1]
-  )
-  x$ROPE_low <- x$ROPE_high <- NULL
+  # check if we have multiple ROPE values
+  if (insight::n_unique(x$ROPE_low) > 1) {
+    caption <- "Proportion of samples inside the ROPE"
+  } else {
+    caption <- sprintf(
+      "Proportion of samples inside the ROPE [%.*f, %.*f]",
+      digits,
+      x$ROPE_low[1],
+      digits,
+      x$ROPE_high[1]
+    )
+    x$ROPE_low <- x$ROPE_high <- NULL
+  }
   .print_html_default(x = x, digits = digits, caption = caption, ci_string = "ROPE", ...)
 }
 
 
 #' @export
 print_html.p_significance <- function(x, digits = 2, ...) {
-  caption <- sprintf(
-    "Practical Significance (threshold: %s)",
-    insight::format_value(attributes(x)$threshold, digits = digits)
-  )
-  .print_html_default(x = x, digits = digits, caption = caption, ...)
+  threshold <- attributes(x)$threshold
+  if (is.list(threshold)) {
+    caption <- "Practical Significance"
+    out <- as.data.frame(do.call(rbind, threshold))
+    colnames(out) <- c("ROPE_low", "ROPE_high")
+    x$ROPE_low <- out$ROPE_low
+    x$ROPE_high <- out$ROPE_high
+    ci_string <- "ROPE"
+  } else {
+    caption <- sprintf(
+      "Practical Significance (threshold: %s)",
+      insight::format_value(attributes(x)$threshold, digits = digits)
+    )
+    ci_string <- NULL
+  }
+  .print_html_default(x = x, digits = digits, caption = caption, ci_string = ci_string, ...)
 }
 
 
@@ -75,8 +86,6 @@ print_html.bayestestR_si <- function(x, digits = 2, caption = "Support Interval"
 }
 
 
-
-
 # special handling for bayes factors ------------------
 
 
@@ -93,7 +102,7 @@ print_html.bayesfactor_models <- function(x,
     log = log,
     show_names = show_names,
     caption = caption,
-    align = c("llr"),
+    align = "llr",
     ...
   )
 }
@@ -110,7 +119,7 @@ print_html.bayesfactor_inclusion <- function(x,
     digits = digits,
     log = log,
     caption = caption,
-    align = c("lrrr"),
+    align = "lrrr",
     ...
   )
 }
@@ -145,9 +154,6 @@ print_html.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
 }
 
 
-
-
-
 # util ---------------
 
 
@@ -177,7 +183,6 @@ print_html.bayesfactor_parameters <- function(x, digits = 3, log = FALSE, ...) {
 }
 
 
-
 .print_bf_html_default <- function(x,
                                    digits = 3,
                                    log = FALSE,
